Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2886)

Unified Diff: ash/wm/gestures/long_press_affordance_handler.h

Issue 23531053: ui/base/animation -> ui/gfx/animation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge 2 trunk Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/wm/frame_painter.cc ('k') | ash/wm/gestures/long_press_affordance_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/wm/gestures/long_press_affordance_handler.h
diff --git a/ash/wm/gestures/long_press_affordance_handler.h b/ash/wm/gestures/long_press_affordance_handler.h
index 14ff0f3c1ff4494340906b2c0a665880e2a58307..5fe6e00937a0e134c0477ff77488e9d1d0c47672 100644
--- a/ash/wm/gestures/long_press_affordance_handler.h
+++ b/ash/wm/gestures/long_press_affordance_handler.h
@@ -6,8 +6,8 @@
#define ASH_WM_GESTURES_LONG_PRESS_AFFORDANCE_HANDLER_H_
#include "base/timer/timer.h"
-#include "ui/base/animation/animation_delegate.h"
-#include "ui/base/animation/linear_animation.h"
+#include "ui/gfx/animation/animation_delegate.h"
+#include "ui/gfx/animation/linear_animation.h"
#include "ui/gfx/point.h"
namespace aura {
@@ -33,8 +33,8 @@ namespace internal {
// during grow animation.
// The second part is a shrink animation that start after grow and shrinks the
// affordance out of view.
-class LongPressAffordanceHandler : public ui::AnimationDelegate,
- public ui::LinearAnimation {
+class LongPressAffordanceHandler : public gfx::AnimationDelegate,
+ public gfx::LinearAnimation {
public:
LongPressAffordanceHandler();
virtual ~LongPressAffordanceHandler();
@@ -56,12 +56,12 @@ class LongPressAffordanceHandler : public ui::AnimationDelegate,
void StartAnimation();
void StopAnimation();
// Overridden from ui::LinearAnimation.
virtual void AnimateToState(double state) OVERRIDE;
virtual bool ShouldSendCanceledFromStop() OVERRIDE;
- // Overridden from ui::AnimationDelegate.
- virtual void AnimationEnded(const ui::Animation* animation) OVERRIDE;
+ // Overridden from gfx::AnimationDelegate.
+ virtual void AnimationEnded(const gfx::Animation* animation) OVERRIDE;
class LongPressAffordanceView;
scoped_ptr<LongPressAffordanceView> view_;
« no previous file with comments | « ash/wm/frame_painter.cc ('k') | ash/wm/gestures/long_press_affordance_handler.cc » ('j') | no next file with comments »
@@ -56,12 +56,12 @@ class LongPressAffordanceHandler : public ui::AnimationDelegate,
void StartAnimation();
void StopAnimation();
- // Overridden from ui::LinearAnimation.
+ // Overridden from gfx::LinearAnimation.
virtual void AnimateToState(double state) OVERRIDE;
virtual bool ShouldSendCanceledFromStop() OVERRIDE;

Powered by Google App Engine
This is Rietveld 408576698